@@ -120,7 +120,7 @@ class Program(object):
     def print_version(self):
         print 'Verison: %s' % self.prog_info.PROG_VERSION
     
-    def send_notification(self, alert = False):
+    def send_error(self, code, message, errinfo):
         pass
     
         
@@ -291,9 +291,9 @@ def main(prog_or_class, singleton = SINGLETON_NOT_SINGLETON, multiproc_logging =
     prog.prog_args = valuebag.ValueBag(vars(prog.argparser.parse_args()))
 
     ret = 0
+    errinfo = None
     exit_code = 0
     exit_message = ''
-    #send_notification = False
     try:
         logger.info('Entering main program.')
         ret = prog.run()
@@ -325,10 +325,11 @@ def main(prog_or_class, singleton = SINGLETON_NOT_SINGLETON, multiproc_logging =
         
     if exit_code:
         try:
-            logger.info('Sending notification.')
-            prog.send_notification(alert = True)
+            logger.info('Sending error notification.')
+            prog.send_error(exit_code, exit_message, errinfo)
         except:
-            pass
+            logger.error(trackback.format_exc())
+            logger.error('Cant send notification.')
             
     prog.exit(exit_code, exit_message)
     
